/*
 * APICloud JavaScript Library
 * Copyright (c) 2014 apicloud.com
 */

(function(window){

    var u = {};
    var isAndroid = (/android/gi).test(navigator.appVersion);
    var uzStorage = function(){
        var ls = window.localStorage;
        if(isAndroid){
            ls = os.localStorage();
        }
        return ls;
    };
    function parseArguments(url, data, fnSuc, dataType) {
        if (typeof(data) == 'function') {
            dataType = fnSuc;
            fnSuc = data;
            data = undefined;
        }
        if (typeof(fnSuc) != 'function') {
            dataType = fnSuc;
            fnSuc = undefined;
        }
        return {
            url: url,
            data: data,
            fnSuc: fnSuc,
            dataType: dataType
        };
    }
    u.trim = function(str){
        if(String.prototype.trim){
            return str == null ? "" : String.prototype.trim.call(str);
        }else{
            return str.replace(/(^\s*)|(\s*$)/g, "");
        }
    };
    u.trimAll = function(str){
        return str.replace(/\s*/g,'');
    };
    u.isElement = function(obj){
        return !!(obj && obj.nodeType == 1);
    };
    u.isArray = function(obj){
        if(Array.isArray){
            return Array.isArray(obj);
        }else{
            return obj instanceof Array;
        }
    };
    u.isEmptyObject = function(obj){
        if(JSON.stringify(obj) === '{}'){
            return true;
        }
        return false;
    };
    u.addEvt = function(el, name, fn, useCapture){
        if(!u.isElement(el)){
            console.warn('$api.addEvt Function need el param, el param must be DOM Element');
            return;
        }
        useCapture = useCapture || false;
        if(el.addEventListener) {
            el.addEventListener(name, fn, useCapture);
        }
    };
    u.rmEvt = function(el, name, fn, useCapture){
        if(!u.isElement(el)){
            console.warn('$api.rmEvt Function need el param, el param must be DOM Element');
            return;
        }
        useCapture = useCapture || false;
        if (el.removeEventListener) {
            el.removeEventListener(name, fn, useCapture);
        }
    };
    u.one = function(el, name, fn, useCapture){
        if(!u.isElement(el)){
            console.warn('$api.one Function need el param, el param must be DOM Element');
            return;
        }
        useCapture = useCapture || false;
        var that = this;
        var cb = function(){
            fn && fn();
            that.rmEvt(el, name, cb, useCapture);
        };
        that.addEvt(el, name, cb, useCapture);
    };
    u.dom = function(el, selector){
        if(arguments.length === 1 && typeof arguments[0] == 'string'){
            if(document.querySelector){
                return document.querySelector(arguments[0]);
            }
        }else if(arguments.length === 2){
            if(el.querySelector){
                return el.querySelector(selector);
            }
        }
    };
    u.domAll = function(el, selector){
        if(arguments.length === 1 && typeof arguments[0] == 'string'){
            if(document.querySelectorAll){
                return document.querySelectorAll(arguments[0]);
            }
        }else if(arguments.length === 2){
            if(el.querySelectorAll){
                return el.querySelectorAll(selector);
            }
        }
    };
    u.byId = function(id){
        return document.getElementById(id);
    };
    u.first = function(el, selector){
        if(arguments.length === 1){
            if(!u.isElement(el)){
                console.warn('$api.first Function need el param, el param must be DOM Element');
                return;
            }
            return el.children[0];
        }
        if(arguments.length === 2){
            return this.dom(el, selector+':first-child');
        }
    };
    u.last = function(el, selector){
        if(arguments.length === 1){
            if(!u.isElement(el)){
                console.warn('$api.last Function need el param, el param must be DOM Element');
                return;
            }
            var children = el.children;
            return children[children.length - 1];
        }
        if(arguments.length === 2){
            return this.dom(el, selector+':last-child');
        }
    };
    u.eq = function(el, index){
        return this.dom(el, ':nth-child('+ index +')');
    };
    u.not = function(el, selector){
        return this.domAll(el, ':not('+ selector +')');
    };
    u.prev = function(el){
        if(!u.isElement(el)){
            console.warn('$api.prev Function need el param, el param must be DOM Element');
            return;
        }
        var node = el.previousSibling;
        if(node.nodeType && node.nodeType === 3){
            node = node.previousSibling;
            return node;
        }
    };
    u.next = function(el){
        if(!u.isElement(el)){
            console.warn('$api.next Function need el param, el param must be DOM Element');
            return;
        }
        var node = el.nextSibling;
        if(node.nodeType && node.nodeType === 3){
            node = node.nextSibling;
            return node;
        }
    };
    u.closest = function(el, selector){
        if(!u.isElement(el)){
            console.warn('$api.closest Function need el param, el param must be DOM Element');
            return;
        }
        var doms, targetDom;
        var isSame = function(doms, el){
            var i = 0, len = doms.length;
            for(i; i<len; i++){
                if(doms[i].isEqualNode(el)){
                    return doms[i];
                }
            }
            return false;
        };
        var traversal = function(el, selector){
            doms = u.domAll(el.parentNode, selector);
            targetDom = isSame(doms, el);
            while(!targetDom){
                el = el.parentNode;
                if(el != null && el.nodeType == el.DOCUMENT_NODE){
                    return false;
                }
                traversal(el, selector);
            }

            return targetDom;
        };

        return traversal(el, selector);
    };
    u.contains = function(parent,el){
        var mark = false;
        if(el === parent){
            mark = true;
            return mark;
        }else{
            do{
                el = el.parentNode;
                if(el === parent){
                    mark = true;
                    return mark;
                }
            }while(el === document.body || el === document.documentElement);

            return mark;
        }

    };
    u.remove = function(el){
        if(el && el.parentNode){
            el.parentNode.removeChild(el);
        }
    };
    u.attr = function(el, name, value){
        if(!u.isElement(el)){
            console.warn('$api.attr Function need el param, el param must be DOM Element');
            return;
        }
        if(arguments.length == 2){
            return el.getAttribute(name);
        }else if(arguments.length == 3){
            el.setAttribute(name, value);
            return el;
        }
    };
    u.removeAttr = function(el, name){
        if(!u.isElement(el)){
            console.warn('$api.removeAttr Function need el param, el param must be DOM Element');
            return;
        }
        if(arguments.length === 2){
            el.removeAttribute(name);
        }
    };
    u.hasCls = function(el, cls){
        if(!u.isElement(el)){
            console.warn('$api.hasCls Function need el param, el param must be DOM Element');
            return;
        }
        if(el.className.indexOf(cls) > -1){
            return true;
        }else{
            return false;
        }
    };
    u.addCls = function(el, cls){
        if(!u.isElement(el)){
            console.warn('$api.addCls Function need el param, el param must be DOM Element');
            return;
        }
        if('classList' in el){
            el.classList.add(cls);
        }else{
            var preCls = el.className;
            var newCls = preCls +' '+ cls;
            el.className = newCls;
        }
        return el;
    };
    u.removeCls = function(el, cls){
        if(!u.isElement(el)){
            console.warn('$api.removeCls Function need el param, el param must be DOM Element');
            return;
        }
        if('classList' in el){
            el.classList.remove(cls);
        }else{
            var preCls = el.className;
            var newCls = preCls.replace(cls, '');
            el.className = newCls;
        }
        return el;
    };
    u.toggleCls = function(el, cls){
        if(!u.isElement(el)){
            console.warn('$api.toggleCls Function need el param, el param must be DOM Element');
            return;
        }
        if('classList' in el){
            el.classList.toggle(cls);
        }else{
            if(u.hasCls(el, cls)){
                u.removeCls(el, cls);
            }else{
                u.addCls(el, cls);
            }
        }
        return el;
    };
    u.val = function(el, val){
        if(!u.isElement(el)){
            console.warn('$api.val Function need el param, el param must be DOM Element');
            return;
        }
        if(arguments.length === 1){
            switch(el.tagName){
                case 'SELECT':
                    var value = el.options[el.selectedIndex].value;
                    return value;
                    break;
                case 'INPUT':
                    return el.value;
                    break;
                case 'TEXTAREA':
                    return el.value;
                    break;
            }
        }
        if(arguments.length === 2){
            switch(el.tagName){
                case 'SELECT':
                    el.options[el.selectedIndex].value = val;
                    return el;
                    break;
                case 'INPUT':
                    el.value = val;
                    return el;
                    break;
                case 'TEXTAREA':
                    el.value = val;
                    return el;
                    break;
            }
        }

    };
    u.prepend = function(el, html){
        if(!u.isElement(el)){
            console.warn('$api.prepend Function need el param, el param must be DOM Element');
            return;
        }
        el.insertAdjacentHTML('afterbegin', html);
        return el;
    };
    u.append = function(el, html){
        if(!u.isElement(el)){
            console.warn('$api.append Function need el param, el param must be DOM Element');
            return;
        }
        el.insertAdjacentHTML('beforeend', html);
        return el;
    };
    u.before = function(el, html){
        if(!u.isElement(el)){
            console.warn('$api.before Function need el param, el param must be DOM Element');
            return;
        }
        el.insertAdjacentHTML('beforebegin', html);
        return el;
    };
    u.after = function(el, html){
        if(!u.isElement(el)){
            console.warn('$api.after Function need el param, el param must be DOM Element');
            return;
        }
        el.insertAdjacentHTML('afterend', html);
        return el;
    };
    u.html = function(el, html){
        if(!u.isElement(el)){
            console.warn('$api.html Function need el param, el param must be DOM Element');
            return;
        }
        if(arguments.length === 1){
            return el.innerHTML;
        }else if(arguments.length === 2){
            el.innerHTML = html;
            return el;
        }
    };
    u.text = function(el, txt){
        if(!u.isElement(el)){
            console.warn('$api.text Function need el param, el param must be DOM Element');
            return;
        }
        if(arguments.length === 1){
            return el.textContent;
        }else if(arguments.length === 2){
            el.textContent = txt;
            return el;
        }
    };
    u.offset = function(el){
        if(!u.isElement(el)){
            console.warn('$api.offset Function need el param, el param must be DOM Element');
            return;
        }
        var sl = Math.max(document.documentElement.scrollLeft, document.body.scrollLeft);
        var st = Math.max(document.documentElement.scrollTop, document.body.scrollTop);

        var rect = el.getBoundingClientRect();
        return {
            l: rect.left + sl,
            t: rect.top + st,
            w: el.offsetWidth,
            h: el.offsetHeight
        };
    };
    u.css = function(el, css){
        if(!u.isElement(el)){
            console.warn('$api.css Function need el param, el param must be DOM Element');
            return;
        }
        if(typeof css == 'string' && css.indexOf(':') > 0){
            el.style && (el.style.cssText += ';' + css);
        }
    };
    u.cssVal = function(el, prop){
        if(!u.isElement(el)){
            console.warn('$api.cssVal Function need el param, el param must be DOM Element');
            return;
        }
        if(arguments.length === 2){
            var computedStyle = window.getComputedStyle(el, null);
            return computedStyle.getPropertyValue(prop);
        }
    };
    u.jsonToStr = function(json){
        if(typeof json === 'object'){
            return JSON && JSON.stringify(json);
        }
    };
    u.strToJson = function(str){
        if(typeof str === 'string'){
            return JSON && JSON.parse(str);
        }
    };
    u.setStorage = function(key, value){
        if(arguments.length === 2){
            var v = value;
            if(typeof v == 'object'){
                v = JSON.stringify(v);
                v = 'obj-'+ v;
            }else{
                v = 'str-'+ v;
            }
            var ls = uzStorage();
            if(ls){
                ls.setItem(key, v);
            }
        }
    };
    u.getStorage = function(key){
        var ls = uzStorage();
        if(ls){
            var v = ls.getItem(key);
            if(!v){return;}
            if(v.indexOf('obj-') === 0){
                v = v.slice(4);
                return JSON.parse(v);
            }else if(v.indexOf('str-') === 0){
                return v.slice(4);
            }
        }
    };
    u.rmStorage = function(key){
        var ls = uzStorage();
        if(ls && key){
            ls.removeItem(key);
        }
    };
    u.clearStorage = function(){
        var ls = uzStorage();
        if(ls){
            ls.clear();
        }
    };


    /*by king*/
    u.fixIos7Bar = function(el){
        if(!u.isElement(el)){
            console.warn('$api.fixIos7Bar Function need el param, el param must be DOM Element');
            return;
        }
        var strDM = api.systemType;
        if (strDM == 'ios') {
            var strSV = api.systemVersion;
            var numSV = parseInt(strSV,10);

            var fullScreen = api.fullScreen;
            var iOS7StatusBarAppearance = api.iOS7StatusBarAppearance;

            if (numSV >= 7 && !fullScreen && iOS7StatusBarAppearance) {

                el.style.paddingTop = '20px';
            }
        }
    };
    u.fixStatusBar = function(el){
        if(!u.isElement(el)){
            console.warn('$api.fixStatusBar Function need el param, el param must be DOM Element');
            return;
        }
        var sysType = api.systemType;
        if(sysType == 'ios'){
            u.fixIos7Bar(el);
        }else if(sysType == 'android'){
            var ver = api.systemVersion;
            ver = parseFloat(ver);
            var statusBar=api.require("statusBar");


            if(ver >= 4.4){
                statusBar.getHeight(function (ret) {

                    el.style.paddingTop =(ret.height-1)+ 'px';


                })

            }
        }
    };
    u.toast = function(title, text, time){
        var opts = {};
        var show = function(opts, time){
            api.showProgress(opts);
            setTimeout(function(){
                api.hideProgress();
            },time);
        };
        if(arguments.length === 1){
            var time = time || 500;
            if(typeof title === 'number'){
                time = title;
            }else{
                opts.title = title+'';
            }
            show(opts, time);
        }else if(arguments.length === 2){
            var time = time || 500;
            var text = text;
            if(typeof text === "number"){
                var tmp = text;
                time = tmp;
                text = null;
            }
            if(title){
                opts.title = title;
            }
            if(text){
                opts.text = text;
            }
            show(opts, time);
        }
        if(title){
            opts.title = title;
        }
        if(text){
            opts.text = text;
        }
        time = time || 500;
        show(opts, time);
    };
    u.post = function(/*url,data,fnSuc,dataType*/){
        var argsToJson = parseArguments.apply(null, arguments);
        var json = {};
        var fnSuc = argsToJson.fnSuc;
        argsToJson.url && (json.url = argsToJson.url);
        argsToJson.data && (json.data = argsToJson.data);
        if(argsToJson.dataType){
            var type = argsToJson.dataType.toLowerCase();
            if (type == 'text'||type == 'json') {
                json.dataType = type;
            }
        }else{
            json.dataType = 'json';
        }
        json.method = 'post';
        api.ajax(json,
            function(ret,err){
                if (ret) {
                    fnSuc && fnSuc(ret);
                }
            }
        );
    };
    u.get = function(/*url,fnSuc,dataType*/){
        var argsToJson = parseArguments.apply(null, arguments);
        var json = {};
        var fnSuc = argsToJson.fnSuc;
        argsToJson.url && (json.url = argsToJson.url);
        //argsToJson.data && (json.data = argsToJson.data);
        if(argsToJson.dataType){
            var type = argsToJson.dataType.toLowerCase();
            if (type == 'text'||type == 'json') {
                json.dataType = type;
            }
        }else{
            json.dataType = 'text';
        }
        json.method = 'get';
        api.ajax(json,
            function(ret,err){
                if (ret) {
                    fnSuc && fnSuc(ret);
                }
            }
        );
    };

    /*end*/


    window.$api = u;

})(window);



//首页推荐车型
function upDate(ret) {

    var str = "";
    var imgUrl = "";
    for (var i = 0; i < ret.car.length; i++) {
         if (ret.car[i].frontimg == "" || ret.car[i].frontimg == null){
             imgUrl = "../image/default-img.jpg";
         } else {
        imgUrl = urls2 + "/Public" + ret.car[i].frontimg;
        }
        str += '<li tapmode="home-listhover" id="' + ret.car[i].id + '"><div class="list-pic">' +
            '<img src="' + imgUrl + '" />' +
            '</div><div class="list-dis"><div class="list-dis-left">' +
            '<p><span class="txt-line">'+ret.car[i].brand+' |</span><span  style="color: #787878;padding-left:5px">' + ret.car[i].carmodelname + '</span></p>' +
            '<span>' + ret.car[i].agestyle + '年</span> <span class="txt-line">|</span> ' +
            '<span>' + ret.car[i].bearboxtype + '</span> <span class="txt-line">|</span> ' +
            '<span>排量' + ret.car[i].displacement + '</span>' +'</span> <span class="txt-line">|</span> '+
            '<span>' + ret.car[i].sitecount + '座</span>' +
            '</div><div class="list-dis-right"><span></span>' +
            '<i></i></div><div class="clear"></div><div class="list-dis-line"></div><div class="list-dis-zct">' +
            '<div>短租:<i class="short">' + ret.car[i].shortdayprice + '</i>/天 <span class="txt-line">|</span> 周租:<i class="week">' + ret.car[i].weekdayprice + '</i>/天 <span class="txt-line">|</span> 月租:<i class="month">' + ret.car[i].monthdayprice + '</i>/天 </div>' +
            '</div></div></li>';
    }
    $(".home-list").append(str);
}

//正在加载动画
var loadingg='<div id="loading" ><div class="loa"><div class="load-yuan"></div><div class="load-text">载入中.</div></div></div>';
function showLoad() {
    $("body").append(loadingg).on('click',function () {
        return false;
    });
}
function hidenLoad() {
    $("#loading").remove();
}
//加载更多动画
var lodMore='<div class="spinner">' +
    '<div class="bounce1"></div>' +
    '<div class="bounce2"></div>' +
    '<div class="bounce3"></div></div>';
var neterro='<div id="neterro"><img src="../image/neterro.png" />网络故障，请检查网络</div>';
var noorder='<div id="neterro"><img src="../image/orderNo.png" />没有相关订单</div>';
//计算时间之差
function diffDate(startTime, endTime, diffType) {
    //将时间格式转换为可读的格式
    startTime = startTime.replace(/\-/g, "/");
    endTime = endTime.replace(/\-/g, "/");

    //将计算间隔类性字符转换为小写
    diffType = diffType.toLowerCase();
    var sTime = new Date(startTime);      //开始时间
    var eTime = new Date(endTime);  //结束时间
    //作为除数的数字
    var dNum = 1;
    switch (diffType) {
        case "s":
            dNum = 1000;
            break;
        case "m":
            dNum = 1000 * 60;
            break;
        case "h":
            dNum = 1000 * 3600;
            break;
        case "d":
            dNum = 1000 * 3600 * 24;
            break;
        default:
            break;
    }
    return parseInt((eTime.getTime() - sTime.getTime()) / parseInt(dNum));
}
//给YYYY-MM-dd加天数
function dateOperator(date,days,operator){
    date = date.replace("年","-").replace("月","-").replace("日",""); //更改日期格式  
    var nd = new Date(date);
    nd = nd.valueOf();
    if(operator=="+"){
        nd = nd + days * 24 * 60 * 60 * 1000;
    }else if(operator=="-"){
        nd = nd - days * 24 * 60 * 60 * 1000;
    }else{
        return false;
    }
    nd = new Date(nd);
    var y = nd.getFullYear();
    var m = nd.getMonth()+1;
    var d = nd.getDate();
    if(m <= 9) m = "0"+m;
    if(d <= 9) d = "0"+d;
    var cdate = y+"年"+m+"月"+d+"日";
    return cdate;
}



/* 给日期加天数*/
function DateAdd(sdate, days) {
    var a = new Date(sdate);
    a = a.valueOf();
    a = a + days * 24 * 60 * 60 * 1000;
    a = new Date(a);
    var Y=a.getFullYear();
    var M=a.getMonth()+1;
    var D=a.getDate();
    if (M < 10) {
        M = "0" + M;
    }
    if (D < 10) {
        D= "0" + D;
    }
    date=Y+"-"+M+"-"+D;
    return date;
}
function remove(array,index) {
    if(index<=(array.length-1))
    {
        for(var i=index;i<array.length;i++)
        {
            array[i]=array[i+1];
        }
    }
    else
    {
        throw new Error('超出最大索引！');
    }
    array.length=array.length-1;
    return array;
}

//登录注册等待
var loadWater='<div class="sk-circle"><div class="sk-circle1 sk-child"></div><div class="sk-circle2 sk-child"></div>' +
    '<div class="sk-circle3 sk-child"></div><div class="sk-circle4 sk-child"></div>' +
    '<div class="sk-circle5 sk-child"></div><div class="sk-circle6 sk-child"></div>' +
    '<div class="sk-circle7 sk-child"></div><div class="sk-circle8 sk-child"></div>' +
    '<div class="sk-circle9 sk-child"></div>' +
    '<div class="sk-circle10 sk-child"></div><div class="sk-circle11 sk-child"></div>' +
    '<div class="sk-circle12 sk-child"></div></div>';


function sqltime(zc,daijia){

    var today = "";
    //获取服务器时间
    api.ajax({
        url:urls+':9292/getTime',
        method: 'get',
        timeout: 15,
        cache:false,
    },function(ret,err){

        var times = ret.date.split(" ");//截取时间字符串
        var YMD = times[0].split("-");//截取年月日
        var Htime = times[1].split(":");
        var HH = Htime[0];
        var MM = Htime[1];


        var sendStart = YMD[0]+"年"+YMD[1]+"月"+YMD[2]+"日" + " " + HH + ":" + MM;

        api.openWin({
            name: 'ShuttleScalendar',
            url: '../html/ShuttleScalendar.html',
            pageParam: {
                sendStart: sendStart,
                name:zc,
                daijia:daijia
            },
            animation:{
                type:"movein",                //动画类型（详见动画类型常量）
                subType:"from_bottom",       //动画子类型（详见动画子类型常量）
                duration:200
            },
            reload:true,
            bounces: false,
            vScrollBarEnabled: false,
            hScrollBarEnabled: false,
        });




    });
}

function Gettime(fun) {
    var token_v = $api.getStorage('token_v');
        if(token_v!=undefined&&token_v!='undefined'){
            var locatime = new Date();
            var locayear = locatime.getFullYear();
            var locamoth = locatime.getMonth()+1;
            var locaday = locatime.getDate();
            var locahuors = locatime.getHours();
            var locaminnte = locatime.getMinutes();
            var locatoken = locayear+'-'+p(locamoth)+'-'+p(locaday)+' '+p(locahuors)+':'+p(locaminnte);
            var nowtime = locatoken.split(' ');
            var nowtime1 = nowtime[0].split('-');
            var nowtime2 = nowtime[1].split(':');
            var newtimetoken = nowtime1[0]+nowtime1[1]+nowtime1[2]+nowtime2[0]+nowtime2[1];
            var chanum = parseInt(newtimetoken)-parseInt(token_v)+1;

            if(chanum>=5){
                $api.rmStorage('token_v');
                api.ajax({
                    url: urls + ':9292/getTime',
                    method: 'get',
                    timeout: 15,
                    cache: false,
                }, function (ret, err) {

                    if (ret) {
                        var times = ret.date.split(" ");//截取时间字符串
                        var YMD = times[0].split("-");//截取年月日
                        var Htime = times[1].split(":");
                        var upcartime = ret.date;
                        var token_v = YMD[0] + YMD[1] + YMD[2] + Htime[0] + Htime[1];
                        $api.setStorage('token_v', token_v);
                        fun(token_v);

                    }
                })
            }else{
                fun(token_v);
            }
         }else{
         api.ajax({
                url: urls +':9292/getTime',
                method: 'get',
                timeout: 15,
                cache: false,
            }, function (ret, err) {

                if(ret){
                    var times = ret.date.split(" ");//截取时间字符串
                    var YMD = times[0].split("-");//截取年月日
                    var Htime = times[1].split(":");
                    var upcartime = ret.date;
                    var token_v = YMD[0] + YMD[1] + YMD[2] + Htime[0] + Htime[1];
                    $api.setStorage('token_v', token_v);
                    fun(token_v);
                }
            })
    }


}
// 对Date的扩展，将 Date 转化为指定格式的String
// 月(M)、日(d)、小时(h)、分(m)、秒(s)、季度(q) 可以用 1-2 个占位符， 
// 年(y)可以用 1-4 个占位符，毫秒(S)只能用 1 个占位符(是 1-3 位的数字) 
// 例子： 
// (new Date()).Format("yyyy-MM-dd hh:mm:ss.S") ==> 2006-07-02 08:09:04.423 
// (new Date()).Format("yyyy-M-d h:m:s.S")      ==> 2006-7-2 8:9:4.18 
Date.prototype.Format = function (fmt) { //author: meizz 
    var o = {
        "M+": this.getMonth() + 1, //月份 
        "d+": this.getDate(), //日 
        "h+": this.getHours(), //小时 
        "m+": this.getMinutes(), //分 
        "s+": this.getSeconds(), //秒 
        "q+": Math.floor((this.getMonth() + 3) / 3), //季度 
        "S": this.getMilliseconds() //毫秒 
    };
    if (/(y+)/.test(fmt)) fmt = fmt.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
    for (var k in o)
        if (new RegExp("(" + k + ")").test(fmt)) fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
    return fmt;
}
function p(s) {
    return s < 10 ? '0' + s: s;
}
var loadings='<div class="loa" style="background:rgba(0,0,0,0.7); margin-top:-80px;"><div class="load-yuan"></div><div class="load-text">正在录音，请说话</div></div>';

function spech(biaos,fun) {

    var iflyRecognition = api.require('iflyRecognition');
    iflyRecognition.createUtility({
        ios_appid: '5b5ed738',
        android_appid:'5b5ed57e'
    }, function(ret, err) {
        if (ret.status) {
            $('body').append(loadings);
        } else {

        }
    });

    iflyRecognition.record({
        vadbos:6000,
        vadeos:1000,
        asrptt: 1
    }, function(ret, err) {
        if(ret) {
            if (ret.status && ret.wordStr!='') {
                iflyRecognition.cancelRecord();
                iflyRecognition.stopRecord();
                $(".loa").remove();
                var wordStr = ret.wordStr;
                iflyRecognition.read({
                    readStr: ret.wordStr,
                    speed: 30,
                    volume: 100,
                    voice: 0,
                    rate: 16000
                }, function (ret, err) {
                    if(ret) {
                        if (ret.status) {
                            if (ret.speakProgress == 100) {
                                switchall(wordStr,biaos,function (sta,indexs) {
                                    fun(sta,indexs)
                                });
                            }
                        }
                    }else{
                        fun(0,'')
                    }
                });
            } else {
                $(".loa").remove();
                iflyRecognition.read({
                    readStr: '抱歉，请您放慢语速，重新录音',
                    speed: 60,
                    volume: 100,
                    voice: 0,
                    rate: 16000
                }, function (ret, err) {
                    if(ret){
                        if(ret.status && ret.speakProgress == 100){
                            iflyRecognition.cancelRecord();
                            iflyRecognition.stopRecord();
                            fun(0,'')
                        }
                    }
                })
                return false;
            }
        }else{
            $(".loa").remove();

            iflyRecognition.cancelRecord();
            iflyRecognition.stopRecord();
            fun(0,'')
            return false;

        }
    });


}
//页面 辨识选择
function switchall(wordStr,biaos,fun) {
    var iflyRecognition = api.require('iflyRecognition');
    iflyRecognition.createUtility({
        ios_appid:'5b5ed738',
        android_appid:'5b5ed57e'
    }, function(ret, err) {
        if (ret.status) {

        } else {

        }
    });
    if(isNaN(biaos)){
        var cen = biaos.split('_');
        biaos =parseInt(cen[0]);
    }
    else{
        biaos = biaos;
    }

    switch(biaos)
    {
        //首页
        case 0:
            if (wordStr.indexOf('租车') >= 0) {
                api.openWin({
                    name: 'win_rencar',
                    url: '../html/renCar.html'
                });
                fun(1,'')
                return false;
            }
            if (wordStr.indexOf('专车') >= 0 || wordStr.indexOf('专车接送') >= 0 || wordStr.indexOf('预约车')>=0) {
                var phone = $api.getStorage('phone');
                if (phone != '' && phone != null) {
                    api.openWin({
                        name: 'ShuttleBus',
                        url: '../html/ShuttleBus.html',
                        slidBackEnabled:false
                    });
                } else {
                    api.openWin({
                        name: 'login',
                        url: '../html/login.html'
                    });
                }
                fun(1,'')
                return false;
            }
            if (wordStr.indexOf('登录') >= 0) {
                var userid = $api.getStorage('urserId');
                if (userid == undefined) {
                    api.openWin({
                        name: 'login',
                        url: '../html/login.html'
                    });
                } else {
                    speechRecognizer.read({
                        readStr: '您当前已登录，不能重复登录',
                        speed: 30,
                        volume: 100,
                        voice: 0,
                        rate: 16000
                    }, function (ret, err) {
                    })
                }
                fun(1,'')
                return false;
            }
            if (wordStr.indexOf('接送车') >= 0 || wordStr.indexOf('接车') >= 0 || wordStr.indexOf('送车') >= 0||wordStr.indexOf('接送火车') >= 0) {
                var phone = $api.getStorage('phone');
                if (phone != '' && phone != null) {
                    api.openWin({
                        name: 'ShuttleCar',
                        url: '../html/ShuttleCar.html',
                        slidBackEnabled:false
                    });
                } else {
                    api.openWin({
                        name: 'login',
                        url: '../html/login.html'
                    });
                }
                fun(1,'')
                return false;
            }
            if (wordStr.indexOf('接送机') >= 0 || wordStr.indexOf('接机') >= 0 || wordStr.indexOf('送机') >= 0||wordStr.indexOf('接送飞机') >= 0) {
                var phone = $api.getStorage('phone');
                if (phone != '' && phone != null) {
                    api.openWin({
                        name: 'ShuttlePlane',
                        url: '../html/ShuttlePlane.html',
                        slidBackEnabled:false
                    });
                } else {
                    api.openWin({
                        name: 'login',
                        url: '../html/login.html'
                    });
                }
                fun(1,'')
                return false;
            }
            iflyRecognition.read({
                readStr: '抱歉，您说的操作在当前页无法执行，请重新录音',
                speed: 60,
                volume: 100,
                voice: 0,
                rate: 16000
            }, function (ret, err) {
                if(ret){
                    if(ret.status && ret.speakProgress == 100){
                        fun(0,'')
                    }
                }

            })
            break;
        case 1:
            if (wordStr.indexOf('筛选') >= 0) {
                var stats = '筛选';
                fun(stats,'')
                return false;
            }
            if (wordStr.indexOf('升序') >= 0) {
                var stats = '升序';
                fun(stats,'')
                return false;
            }
            if (wordStr.indexOf('降序') >= 0) {
                var stats = '降序';
                fun(stats,'')
                return false;
            }
            iflyRecognition.read({
                readStr: '抱歉，您说的操作在当前页无法执行，请重新录音',
                speed: 60,
                volume: 100,
                voice: 0,
                rate: 16000
            }, function (ret, err) {
                if(ret){
                    if(ret.status && ret.speakProgress == 100){
                        fun('','');
                        return false;
                    }
                }

            })
            break;
        case 101:
            var character = new Array("a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z");
            for(var i=0;i<25;i++)
            {
                if (wordStr.indexOf('品牌'+character[i]+'') >= 0) {
                    var stats = character[i];
                    fun(stats,i)
                    return false;
                }
            }
            iflyRecognition.read({
                readStr: '抱歉，您说的操作在当前页无法执行，请重新录音',
                speed: 60,
                volume: 100,
                voice: 0,
                rate: 16000
            }, function (ret, err) {
                if(ret){
                    if(ret.status && ret.speakProgress == 100){
                        fun('','')
                    }
                }

            })

            break;
        case 1011:

            api.ajax({
                url: urls + ':9292/brand?en='+cen[1],
                method: 'get',
                timeout: 15,
                returnAll: false
            }, function (ret, err) {
                var str = '';
                if (ret) {
                    if (ret.error == 1) {
                        api.toast({msg: '暂时没有数据', location: 'middle'});
                    } else {
                        for (var i = 0; i < ret.brand.length; i++) {
                            if (wordStr.indexOf('品牌'+ret.brand[i].brand+'') >= 0) {
                                var stats = ret.brand[i].brand;
                                fun(stats,i)
                                return false;
                            }
                        }
                    }
                } else {
                    api.toast({msg: '网络出现问题了！', location: 'middle'});
                }
            });

            iflyRecognition.read({
                readStr: '抱歉，您说的操作在当前页无法执行，请重新录音',
                speed: 60,
                volume: 100,
                voice: 0,
                rate: 16000
            }, function (ret, err) {
                if(ret){
                    if(ret.status && ret.speakProgress == 100){
                        fun('','')
                    }
                }

            })

            break;
        case 102:
            var character = new Array("商务车","越野车","轿车","面包车","客车");
            for(var i=0;i<character.length;i++)
            {
                if (wordStr.indexOf('车型'+character[i]+'') >= 0) {
                    var stats = character[i];
                    fun(stats,i)
                    return false;
                }
            }
            iflyRecognition.read({
                readStr: '抱歉，您说的操作在当前页无法执行，请重新录音',
                speed: 60,
                volume: 100,
                voice: 0,
                rate: 16000
            }, function (ret, err) {
                if(ret){
                    if(ret.status && ret.speakProgress == 100){

                        fun('','')
                        return false;
                    }
                }

            })
            break;
        case 103:
            var character = new Array("自动","手动");
            for(var i=0;i<character.length;i++)
            {
                if (wordStr.indexOf('变速箱'+character[i]+'') >= 0) {
                    var stats = character[i];
                    fun(stats,i)
                    return false;
                }
            }
            iflyRecognition.read({
                readStr: '抱歉，您说的操作在当前页无法执行，请重新录音',
                speed: 60,
                volume: 100,
                voice: 0,
                rate: 16000
            }, function (ret, err) {
                if(ret){
                    if(ret.status && ret.speakProgress == 100){
                        fun('','')
                        return false;

                    }
                }

            })
            break;
        case 2:

            break;
        case 3:

            break;
        case 4:

            break;
        case 5:

            break;
        case 6:

            break;
        default:

    }

}
/*计算价格函数*/
// 起步价:StartFare

// 单程加价公里:UpPriceStartMile 超过公里数
// 计程单价公里:UnitPricePerMile 里程费单价
// 计程单价时间:UnitPricePerMinute 时长费单价
// 单程加价单价:UpPrice 远途费 单价
//夜间费用单价:NightPricePerMile

//预计上车时间：usertime
//预计里程数：userdistance
//预计总时间：useralltime
function Calprice(usertime,userdistance,useralltime,StartFare,UpPriceStartMile,UnitPricePerMile,UnitPricePerMinute,UpPrice,NightPricePerMile,nightstart,nightend) {
    //晚上
   //alert(usertime+','+userdistance+','+useralltime+','+StartFare+','+StartMile+','+UpPriceStartMile+','+UnitPricePerMile+','+UnitPricePerMinute+','+UpPrice+','+PeakUnitPrice+','+PeakPriceStartMile+','+LowSpeedPricePerminute+','+MorningPeakTimeOn+','+MorningPeakTimeOff+','+EveningPeakTimeOn+','+EveningPeakTimeOff)
    if(usertime >= nightstart || usertime < nightend){
        //不超起步里程
        if(userdistance <= UpPriceStartMile){
            //起步价+ 里程费（总里程*单价公里）+ 时长费（总时间*总里程）+夜间费（总里程*夜间每公里单价）
            var retupric = StartFare  + UnitPricePerMile * userdistance + useralltime * UnitPricePerMinute + NightPricePerMile * userdistance;
            return retupric;
        }
        //超起步里程
        if(userdistance > UpPriceStartMile) {

            //超过单程加价10公里   起步价 + 里程费（总里程*单价公里）+ 远途费（总里程-超过指定标准里程（10））+ 时长费（总时间*总里程）+夜间费（总里程*夜间每公里单价）
            var retupric =StartFare + UnitPricePerMile * userdistance + UpPrice * (userdistance - UpPriceStartMile) + useralltime * UnitPricePerMinute + NightPricePerMile * userdistance;
            return retupric;
        }
}
    //白天
    else{
        //不超起步里程
        if(userdistance <= UpPriceStartMile){
            //起步价+ 里程费（总里程*单价公里）+ 时长费（总时间*总里程）
            var retupric = StartFare + useralltime * UnitPricePerMinute + UnitPricePerMile * userdistance;
            return retupric;
        }
        //超起步里程
        if(userdistance > UpPriceStartMile) {

            //超过单程加价公里
            var retupric = StartFare + UnitPricePerMile * userdistance + UpPrice * (userdistance - UpPriceStartMile) + useralltime * UnitPricePerMinute;

            return retupric;
        }

    }
}
function bd_decrypt(bd_lng, bd_lat) {
    var X_PI = Math.PI * 3000.0 / 180.0;
    var x = bd_lng - 0.0065;
    var y = bd_lat - 0.006;
    var z = Math.sqrt(x * x + y * y) - 0.00002 * Math.sin(y * X_PI);
    var theta = Math.atan2(y, x) - 0.000003 * Math.cos(x * X_PI);
    var gg_lng = z * Math.cos(theta);
    var gg_lat = z * Math.sin(theta);
    return {lng: gg_lng, lat: gg_lat}

}

var perms = new Array();
perms = ['contacts','location','microphone','phone','sms','storage'];
var Listarr = new Array();
function hasPermission(){
    var rets = api.hasPermission({
        list:perms
    });


        for (var i = 0; i < rets.length; i++) {
            if (rets[i].granted == false) {

               Listarr.push(rets[i].name);
            }

        }
     if(Listarr.length>0){
         reqPermission(Listarr)
     }else{
         return true;
     }





}

function reqPermission(one){

    api.requestPermission({
        list: one,
        code: 100001
    }, function(ret, err){
        if(ret){
            api.sendEvent({
                name: 'shuaxinindex',
            });
        }
    });






}

function MytoFixed(number,fractionDigits){
    var times = Math.pow(10, fractionDigits);
    var roundNum = Math.round(number * times) / times;
    return roundNum.toFixed(fractionDigits);
}

function wgs84togcj02tobd09 (lng, lat) {
    const xPI = 3.14159265358979324 * 3000.0 / 180.0;
    const PI = 3.1415926535897932384626;
    const a = 6378245.0;
    const ee = 0.00669342162296594323;
    // WGS84转GCj02
    var dlat = transformlat(lng - 105.0, lat - 35.0);
    var dlng = transformlng(lng - 105.0, lat - 35.0);
    var radlat = lat / 180.0 * PI;
    var magic = Math.sin(radlat);
    magic = 1 - ee * magic * magic;
    var sqrtmagic = Math.sqrt(magic);
    dlat = (dlat * 180.0) / ((a * (1 - ee)) / (magic * sqrtmagic) * PI);
    dlng = (dlng * 180.0) / (a / sqrtmagic * Math.cos(radlat) * PI);
    var mglat = lat + dlat;
    var mglng = lng + dlng;
    // 火星坐标系 (GCJ-02) 与百度坐标系 (BD-09) 的转换
    var z = Math.sqrt(mglng * mglng + mglat * mglat) + 0.00002 * Math.sin(mglat * xPI);
    var theta = Math.atan2(mglat, mglng) + 0.000003 * Math.cos(mglng * xPI);
    var bdlng = z * Math.cos(theta) + 0.0065;
    var bdlat = z * Math.sin(theta) + 0.006;
    return [bdlng, bdlat]
    //return [mglng, mglat]
    //return {lng: bdlng, lat: bdlat}
    function transformlat (lng, lat) {
        const PI = 3.1415926535897932384626;
        var  ret = -100.0 + 2.0 * lng + 3.0 * lat + 0.2 * lat * lat + 0.1 * lng * lat + 0.2 * Math.sqrt(Math.abs(lng));
        ret += (20.0 * Math.sin(6.0 * lng * PI) + 20.0 * Math.sin(2.0 * lng * PI)) * 2.0 / 3.0;
        ret += (20.0 * Math.sin(lat * PI) + 40.0 * Math.sin(lat / 3.0 * PI)) * 2.0 / 3.0;
        ret += (160.0 * Math.sin(lat / 12.0 * PI) + 320 * Math.sin(lat * PI / 30.0)) * 2.0 / 3.0;
        return ret
    }
    function transformlng (lng, lat) {
        const PI = 3.1415926535897932384626;
        var ret = 300.0 + lng + 2.0 * lat + 0.1 * lng * lng + 0.1 * lng * lat + 0.1 * Math.sqrt(Math.abs(lng));
        ret += (20.0 * Math.sin(6.0 * lng * PI) + 20.0 * Math.sin(2.0 * lng * PI)) * 2.0 / 3.0;
        ret += (20.0 * Math.sin(lng * PI) + 40.0 * Math.sin(lng / 3.0 * PI)) * 2.0 / 3.0;
        ret += (150.0 * Math.sin(lng / 12.0 * PI) + 300.0 * Math.sin(lng / 30.0 * PI)) * 2.0 / 3.0;
        return ret
    }

}